==> eiffelstudio-16.05.tar: F_code/C2/po91.c <==
/*
 * Code for class PO_FILE_ENTRY_PLURAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po91.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_ENTRY_PLURAL}.make */
void F128_1518 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	F127_1494(Current, arg1);
	{
		static EIF_TYPE_INDEX typarr0[] = {605,671,896,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F606_4010(RTCW(tr1), NULL, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 2L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	tr2 = RTMS_EX_H("",0,0);
	tr2 = F888_6651(tr2);
	tr2 = F127_1508(Current, tr2);
	F606_4036(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L));
	{
		static EIF_TYPE_INDEX typarr0[] = {671,896,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F672_4137(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_ENTRY_PLURAL}.set_msgid_plural */
void F128_1519 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R1934[Dtype(tr1)-671])(RTCW(tr1));
	tr1 = F888_6651(RTCW(arg1));
	tr1 = F127_1508(Current, tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_ENTRY_PLURAL}.to_string */
EIF_REFERENCE F128_1524 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	Result = F127_1507(Current);
	tr1 = RTMS_EX_H("msgid_plural",12,1254930796);
	tr1 = F888_6651(tr1);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr1 = F127_1511(Current, tr1, tr2);
	F897_6982(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	loc1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_1_);
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_0_);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tb3 = F606_4030(RTCW(tr1), loc1);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = F606_4015(RTCW(tr1), loc1);
			tb2 = (EIF_BOOLEAN)(tr1 != NULL);
		}
		if (tb2) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = F606_4015(RTCW(tr1), loc1);
			tb2 = F285_2591(RTCW(tr1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			tr1 = RTMS_EX_H("msgstr[",7,1190922843);
			tr2 = c_outi(loc1);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R4901[Dtype(tr1)-890])(tr1, tr2);
			tr2 = RTMS_EX_H("]",1,93);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R4901[Dtype(tr1)-890])(RTCW(tr1), tr2);
			tr1 = F888_6651(RTCW(tr1));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr2 = F606_4015(RTCW(tr2), loc1);
			tr1 = F127_1511(Current, tr1, tr2);
			F897_6982(RTCW(Result), tr1);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {PO_FILE_ENTRY_PLURAL}.msgstr_n_lines */
EIF_REFERENCE F128_1525 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {PO_FILE_ENTRY_PLURAL}.msgid_plural_lines */
EIF_REFERENCE F128_1526 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


void EIF_Minit91 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C2/po91.c <==
/*
 * Code for class PO_FILE_ENTRY_PLURAL
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "po91.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {PO_FILE_ENTRY_PLURAL}.make */
void F128_1548 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTGC;
	F127_1525(Current, arg1, arg2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,606,0xFF01,672,0xFF01,947,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	tr2 = RTMS_EX_H("",0,0);
	tr2 = F939_6880(tr2);
	tr2 = F127_1538(Current, tr2);
	F607_4127(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,672,0xFF01,947,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F673_4254(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_ENTRY_PLURAL}.set_msgid_plural */
void F128_1549 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R1970[Dtype(tr1)-672])(RTCW(tr1));
	tr1 = F939_6880(RTCW(arg1));
	tr1 = F127_1538(Current, tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {PO_FILE_ENTRY_PLURAL}.to_string */
EIF_REFERENCE F128_1554 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	Result = F127_1537(Current);
	tr1 = RTMS_EX_H("msgid_plural",12,1254930796);
	tr1 = F939_6880(tr1);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	tr1 = F127_1541(Current, tr1, tr2);
	F948_7230(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	loc1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_1_);
	for (;;) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_0_);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
		tb3 = F607_4147(RTCW(tr1), loc1);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = F607_4132(RTCW(tr1), loc1);
			tb2 = (EIF_BOOLEAN)(tr1 != NULL);
		}
		if (tb2) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr1 = F607_4132(RTCW(tr1), loc1);
			tb2 = F285_2627(RTCW(tr1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			tr1 = RTMS_EX_H("msgstr[",7,1190922843);
			tr2 = c_outi(loc1);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5081[Dtype(tr1)-942])(tr1, tr2);
			tr2 = RTMS_EX_H("]",1,93);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5081[Dtype(tr1)-942])(RTCW(tr1), tr2);
			tr1 = F939_6880(RTCW(tr1));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr2 = F607_4132(RTCW(tr2), loc1);
			tr1 = F127_1541(Current, tr1, tr2);
			F948_7230(RTCW(Result), tr1);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {PO_FILE_ENTRY_PLURAL}.msgstr_n_lines */
EIF_REFERENCE F128_1555 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {PO_FILE_ENTRY_PLURAL}.msgid_plural_lines */
EIF_REFERENCE F128_1556 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


void EIF_Minit91 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
